"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findByKey = void 0;
/**
 * Retrieves the corresponding enum item for a key;
 * This can be useful for mapping external data to properly typed data.
 * NOTE: due to the way enums work in TypeScript, a handful of quirks apply:
 * - `const` enums cannot be used due to being inlined during compilation.
 *
 * @since 13.0.0
 * @category Enum
 * @param targetEnum Enum to get an item of.
 * @param targetKey Item key to search.
 * @returns Enum item or null if none matched
 * @example
 * enum MyStringEnum {
 *    FOO = "Foo",
 *    BAR = "Bar",
 * }
 * findByKey<MyStringEnum>(MyStringEnum, "FOO");
 * // => MyStringEnum.FOO
 *
 * enum MyStringEnum {
 *    FOO = "Foo",
 *    BAR = "Bar",
 * }
 * findByKey<MyStringEnum>(MyStringEnum, "FIZZ");
 * // => null
 */
exports.findByKey = (targetEnum, targetKey) => {
    for (const key of Object.keys(targetEnum)) {
        if (key === targetKey) {
            return targetEnum[key];
        }
    }
    return null;
};
//# sourceMappingURL=findByKey.js.map