/**
 * Retrieves the corresponding enum item for a value;
 * This can be useful for mapping external data to properly typed data.
 * NOTE: due to the way enums work in TypeScript, a handful of quirks apply:
 * - Do not use enums where the same value is used for multiple items!
 * Either value will be found, however the typing that is returned cannot be guaranteed.
 * - `const` enums cannot be used due to being inlined during compilation.
 *
 * @since 13.0.0
 * @category Enum
 * @param targetEnum Enum to get an item of.
 * @param targetValue Item value to search.
 * @returns Enum item or null if none matched
 * @throws TypeError if not all values in enum are unique.
 * @example
 * enum MyStringEnum {
 *    FOO = "Foo",
 *    BAR = "Bar",
 * }
 * findByValue<MyStringEnum>(MyStringEnum, "Foo");
 * // => MyStringEnum.FOO
 *
 * enum MyStringEnum {
 *    FOO = "Foo",
 *    BAR = "Bar",
 * }
 * findByValue<MyStringEnum>(MyStringEnum, "Fizz");
 * // => null
 */
export declare const findByValue: <TEnum>(targetEnum: Record<string, TEnum[any]>, targetValue: TEnum[any]) => TEnum | null;
//# sourceMappingURL=findByValue.d.ts.map